@@ -10,7 +10,7 @@ function StantonSCS3d() {}
 // ----------   Customization variables ----------
 //      See http://mixxx.org/wiki/doku.php/stanton_scs.3d_mixxx_user_guide  for details
 StantonSCS3d.pitchRanges = [ 0.08, 0.12, 0.5, 1.0 ];    // Pitch ranges for LED off, blue, purple, red
-StantonSCS3d.fastDeckChange = false;    // Skip the flashy lights if true, for juggling
+StantonSCS3d.fastDeckChange = true;    // Skip the flashy lights if true, for juggling
 StantonSCS3d.spinningPlatter = false;    // Spinning platter LEDs // --MidiJ
 StantonSCS3d.spinningPlatterOnlyVinyl = false;  // Only show the spinning platter LEDs in vinyl mode
 StantonSCS3d.VUMeters = true;           // Pre-fader VU meter LEDs
