@@ -27,22 +27,18 @@
 #include "MidiObjectGuiEmul.h"
 #include "MidiObjectUdp.h"
 #include "RouterObject.h"
-#include "SettingsDialog.h"
+#include "settings/SettingsDialog.h"
 #include "Utils.h"
 #include "gui/GuiUtils.h"
+#include "gst/GstUdpAudioPlayer.h"
 
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus>
 #endif // Q_WS_MAEMO_5
 
 
-#define SETTINGS_CURRENTSCHEMEID	"scheme"
-#define SETTINGS_CURRENTCONNECTION	"connection"
 
-#define MIDIJ_FILESCHEMEFILTER		"*.xml"
-
-
-#define WINDOW_BAR_HEIGHT	68
+#define WINDOW_BAR_HEIGHT			68
 
 #define LSPB_INIT					1
 #define LSPB_SCHEMEFILE				2
@@ -52,38 +48,49 @@
 
 
 MidiJ::MidiJ(QWidget *parent)
-    : QGraphicsView(parent)
+    : QWidget(parent)
 {
+#ifdef Q_WS_MAEMO_5
+//	setAttribute(Qt::WA_Maemo5StackedWindow, true); // BUG: some flickering while trying to reopen advanced settings
+#endif
+	m_pView = new QGraphicsView(this);
 //    setStyleSheet(QString::fromUtf8("border: 0px"));
 //    setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
-	setOptimizationFlags(QGraphicsView::DontAdjustForAntialiasing);
-    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-
+	m_pView->setOptimizationFlags(QGraphicsView::DontAdjustForAntialiasing);
+	m_pView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+	m_pView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 	m_scene.setBackgroundBrush(QBrush(Qt::black));
-	setScene(&m_scene);
+	m_pView->setScene(&m_scene);
 
 	m_scene.setSceneRect(QRect(QPoint(0, 0), desktopSize()));
 	m_menuVisible = false;
 	m_menuToggleButton = NULL;
 	m_menuGroup = NULL;
 	m_loadingGroup = NULL;
+	m_netcastManager = NULL;
 
 	m_router = new RouterObject();
 	m_midiControler = new MidiObjectGuiEmul();
 	m_midiConnection = new MidiObjectUdp(MidiObjectUdp::BidirClient);
 	m_midiConnection->updateDeviceList();
+	m_netcastManager = new NetcastManager();
+	m_settings = new SettingsManager();
+
+	QVBoxLayout* layout = new QVBoxLayout();
+	layout->setMargin(0);
+	layout->addWidget(m_pView);
+	setLayout(layout);
 }
 
-//#define _delete(x) if (x){delete x; x=NULL;}
 
 MidiJ::~MidiJ()
 {
-	setScene(NULL);
+	m_pView->setScene(NULL);
 	_delete(m_router);
 	_delete(m_midiControler);
 	_delete(m_midiConnection);
-	qDeleteAll(m_schemeList);
+	_delete(m_netcastManager);
+	_delete(m_settings);
 }
 
 
@@ -93,7 +100,6 @@ void MidiJ::showLoadingScreen(bool show)
 	{
 		// create "Loading screen" items
 		QPixmap loadingBg(desktopSize());
-		//loadingBg.fill(QColor(0,0,0,255));
 		loadingBg.fill(QColor(46,44,45,255));
 		QGraphicsItem* loadingBgItem = new QGraphicsPixmapItem(loadingBg);
 		loadingBgItem->setPos(0, 0);
@@ -128,7 +134,7 @@ void MidiJ::showLoadingScreen(bool show)
 	if (show)
 	{
 		// update full screen
-	    setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
+		m_pView->setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
 	}
 	else
 	{
@@ -139,31 +145,22 @@ void MidiJ::showLoadingScreen(bool show)
 }
 
 
-
 void MidiJ::progressLoadingScreen(int pos)
 {
 	if (m_loadingGroup != NULL && m_loadingGroup->isVisible())
 	{
 		m_progressItem->setProgress(pos);
-		viewport()->repaint(m_progressItemRect);
+		m_pView->viewport()->repaint(m_progressItemRect);
 	}
 }
 
 
-bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
+bool MidiJ::init(QString schemeHomeDir, QString schemeAltDir)
 {
-#ifdef Q_WS_MAEMO_5
-	QSettings settings;
-	m_currentSchemeId = settings.value(SETTINGS_CURRENTSCHEMEID).toString();
-	if (m_currentSchemeId.isEmpty())
-	{
-		m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Blue_Gen.xml").absoluteFilePath();
-	}
-	m_currentMidiConn = settings.value(SETTINGS_CURRENTCONNECTION, "UDP/IP [5004/5]").toString();
-#else
-	m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Stanton_Gen.xml").absoluteFilePath();
-	m_currentMidiConn = "UDP/IP [5004/5]";
-#endif
+	// icon 48x48 for Schemes without icon
+	QIcon defaultSchemeIcon48 = QIcon(":/images/midij_48.png");
+	m_netcastManager->init();
+	m_settings->init(schemeHomeDir, schemeAltDir, defaultSchemeIcon48, m_midiConnection, m_netcastManager);
 
 	// create "Menu" items
 	QPixmap menuBg(desktopSize().width(), WINDOW_BAR_HEIGHT);
@@ -212,7 +209,7 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 		return false;
 	}
 	GraphicsClickItem* settingsButton = new GraphicsClickItem(toolsPix, toolsHiPix, setupButtonRect);
-	connect(settingsButton, SIGNAL(clicked()), SLOT(doSettings()));
+	connect(settingsButton, SIGNAL(clicked()), SLOT(doSettings()), Qt::QueuedConnection);
 
 	m_menuGroup = new GraphicsObjectItemGroup();
 	m_menuGroup->addToGroup(menuBgItem);
@@ -236,44 +233,10 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 
 	m_menuVisible = true;
 
-	// icon 48x48 for Schemes without icon
-	m_defaultSchemeIcon48 = QIcon(":/images/midij_48.png");
+	m_midiConnection->devOpen(m_settings->midiConnection());
+	m_midiConnection->setParams(m_settings->midiConnParams());
 
-	// find scheme header files
-	QStringList fileExtList;
-	fileExtList.append(MIDIJ_FILESCHEMEFILTER);
-
-	DirContext dc1(schemeHomeDir);
-	QDirIterator xmlHeadersIt(QDir::currentPath(), fileExtList, QDir::Files);
-	while (xmlHeadersIt.hasNext())
-	{
-		xmlHeadersIt.next();
-		m_schemeList.append(new SchemeGuiHeader(xmlHeadersIt.fileName()));
-	}
-	dc1.clear();
-	if (QFileInfo(schemeAltDir).isDir())
-	{
-		DirContext dc2(schemeAltDir);
-		QDirIterator xmlHeadersIt(QDir::currentPath(), fileExtList, QDir::Files);
-		while (xmlHeadersIt.hasNext())
-		{
-			xmlHeadersIt.next();
-			m_schemeList.append(new SchemeGuiHeader(xmlHeadersIt.fileName()));
-		}
-	}
-	// remove invalid entries
-	QMutableListIterator<SchemeGuiHeader*> schemesIt(m_schemeList);
-	while (schemesIt.hasNext())
-	{
-		SchemeGuiHeader* guiHeader = schemesIt.next();
-		if (guiHeader == NULL || !guiHeader->isValid())
-		{
-			schemesIt.remove();
-			_delete(guiHeader);
-		}
-	}
-
-	m_midiConnection->devOpen(m_currentMidiConn);
+	m_netcastManager->setConnection(m_settings->netcastConnection(), m_settings->netcastParams());
 
 	progressLoadingScreen(LSPB_INIT);
 	return true;
@@ -290,7 +253,6 @@ bool MidiJ::loadSchemeGui(QString schemeFile)
 
 	QPixmap background = m_guiMapping.background();
 	QRect menuButtonRect = m_guiMapping.toggleButtonRect(WINDOW_BAR_HEIGHT); //(140, 0, 200, 60);
-	// XXX setMenuToggleButton(m_guiMapping.background(), menuButtonRect);
 
 	_delete(m_menuToggleButton);
 	m_menuToggleButton = new GraphicsClickItem(background.copy(menuButtonRect), QPixmap(), menuButtonRect);
@@ -301,7 +263,6 @@ bool MidiJ::loadSchemeGui(QString schemeFile)
 //	m_scene.addItem(m_menuGroup);
 
 	progressLoadingScreen(LSPB_SCHEMEFILE);
-
 	return true;
 }
 
@@ -372,12 +333,12 @@ bool MidiJ::loadSimplePreset()
 
 void MidiJ::loadCurrentScheme()
 {
-	QFileInfo schemeFile(m_currentSchemeId);
+	QFileInfo schemeFile(m_settings->guiScheme());
 	DirContext dc(schemeFile);
 	bool guiLoaded = loadSchemeGui(schemeFile.fileName());
 	if (guiLoaded)
 	{
-		setViewportUpdateMode(QGraphicsView::MinimalViewportUpdate);
+		m_pView->setViewportUpdateMode(QGraphicsView::MinimalViewportUpdate);
 		if (m_guiMapping.hasSourcePreset("engine"))
 			loadEngineRouterPreset();
 		else
@@ -389,7 +350,7 @@ void MidiJ::loadCurrentScheme()
     {
 		QRect menuButtonRect(QRect(QPoint(0,0), desktopSize()));
 		_delete(m_menuToggleButton);
-		QPixmap buttonBg(menuButtonRect.size()/* "etc/img/midij_bg.png"*/);
+		QPixmap buttonBg(menuButtonRect.size());
 		buttonBg.fill(QColor(46,44,45,255));
 		m_menuToggleButton = new GraphicsClickItem(buttonBg, QPixmap(), menuButtonRect);
 		m_menuToggleButton->setZValue(0.0);
@@ -416,17 +377,22 @@ void MidiJ::runScheme()
 		if (midiMapping != NULL)
 			midiMapping->callInit();
 	}
-    if (m_router != NULL)
-    {
-    	RouterMapping* routerMapping = m_router->getRouterMapping();
-    	if (routerMapping != NULL)
-    		routerMapping->callInit();
-    }
+	if (m_router != NULL)
+	{
+		RouterMapping* routerMapping = m_router->getRouterMapping();
+		if (routerMapping != NULL)
+			routerMapping->callInit();
+	}
 
-    if (m_midiConnection->getOpenDevice().isEmpty())
-    {
+	if (m_midiConnection->getOpenDevice().isEmpty())
+	{
 		QMaemo5InformationBox::information(this, "Fail to open network MIDI connection");
-    }
+	}
+	if (m_netcastManager->hasError())
+	{
+		QMaemo5InformationBox::information(this, m_netcastManager->errorMessage());
+	}
+
 	QTimer::singleShot(1000, this, SLOT(menuHide()));
 }
 
@@ -436,16 +402,14 @@ void MidiJ::doClose()
 //    w.setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
 //	QApplication::instance()->processEvents();
 
-#ifdef Q_WS_MAEMO_5
-	QSettings settings;
-	settings.setValue(SETTINGS_CURRENTSCHEMEID, m_currentSchemeId);
-	settings.setValue(SETTINGS_CURRENTCONNECTION, m_currentMidiConn);
-#endif
-
+	if (m_settings)
+		m_settings->close();
 	if (m_midiControler)
 		m_midiControler->devClose();
 	if (m_midiConnection)
 		m_midiConnection->devClose();
+	if (m_netcastManager)
+		m_netcastManager->close();
 
 	close();
 }
@@ -469,23 +433,20 @@ void MidiJ::doTaskView()
 void MidiJ::doSettings()
 {
 	menuHideFast();
-	SettingsDialog dlg;
 
-	dlg.initScheme(m_defaultSchemeIcon48, m_schemeList, m_currentSchemeId);
-	dlg.initMidiConnection(*m_midiConnection->getDeviceList(), m_currentMidiConn);
-	dlg.exec();
-	if (dlg.result() == QDialog::Accepted)
+/*	settings->initScheme(m_defaultSchemeIcon48, m_schemeList, m_currentSchemeId);
+	settings->initMidiConnection(*m_midiConnection->getDeviceList(), m_currentMidiConn);
+	settings->initNetcast(m_netcastManager->connectionList(), m_currentNetcastConn);*/
+	m_settings->execDialog(this);
+	if (m_settings->result() == QDialog::Accepted)
 	{
-		QString newSchemeId = dlg.selectedScheme();
-		QString newMidiConn = dlg.midiConnection();
-
-		if (newMidiConn != m_currentMidiConn)
+		if (m_settings->isMidiConnectionChanged())
 		{
-			m_currentMidiConn = newMidiConn;
-			m_midiConnection->reopen(m_currentMidiConn);
+			m_midiConnection->reopen(m_settings->midiConnection());
+			m_midiConnection->setParams(m_settings->midiConnParams());
 		}
 
-		if (newSchemeId != m_currentSchemeId)
+		if (m_settings->isGuiSchemeChanged())
 		{
 //			QMessageBox::information(this, "debug", QString("<font color=white>newScheme: %1<br>newMidiConn: %2</font>").arg(newScheme).arg(newMidiConn));
 			showLoadingScreen(true);
@@ -500,14 +461,17 @@ void MidiJ::doSettings()
 			m_midiControler->getMidiMapping()->clearPreset();
 
 			// load new skin...
-			m_currentSchemeId = newSchemeId;
 			QTimer::singleShot(250, this, SLOT(loadCurrentScheme()));
 			progressLoadingScreen(LSPB_INIT);
 		}
+
+		if (m_settings->isNetcastConnectionChanged())
+		{
+			m_netcastManager->setConnection(m_settings->netcastConnection(), m_settings->netcastParams());
+		}
 	}
 }
 
-
 void MidiJ::menuHide()
 {
 	if (m_menuVisible && m_menuAnim.state() != QAbstractAnimation::Running)
@@ -577,6 +541,8 @@ QRectF GraphicsProgressItem::boundingRect() const
 
 void GraphicsProgressItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
+	Q_UNUSED(option)
+	Q_UNUSED(widget)
 	painter->setRenderHint(QPainter::Antialiasing);
 	painter->setPen(Qt::NoPen);
 
