@@ -23,8 +23,11 @@
 #include <QGraphicsView>
 #include "gui/MidiMappingGui.h"
 #include <qgraphicsitem.h>
+#include "NetcastManager.h"
+#include "settings/SettingsManager.h"
 
 class MidiObject;
+class MidiObjectUdp;
 class RouterObject;
 class GraphicsClickItem;
 
@@ -70,7 +73,7 @@ protected:
 };
 
 // Main widget
-class MidiJ : public QGraphicsView
+class MidiJ : public QWidget
 {
 	Q_OBJECT
 
@@ -83,7 +86,7 @@ public:
 	virtual ~MidiJ();
 
 	void showLoadingScreen(bool show);
-	bool init(QString homeDir, QString schemeHomeDir, QString schemeAltDir);
+	bool init(QString schemeHomeDir, QString schemeAltDir);
 
 	bool loadSchemeGui(QString schemeFile);
 	bool loadEngineRouterPreset();
@@ -109,17 +112,16 @@ protected:
 	};
 
 private:
+	QGraphicsView* m_pView;
 	QGraphicsScene m_scene;
 	MidiMappingGui m_guiMapping;
+	SettingsManager* m_settings;
 	RouterObject*  m_router;
 	MidiObject*    m_midiControler;
-	MidiObject*    m_midiConnection;
-	QList<SchemeGuiHeader*> m_schemeList;
+	MidiObjectUdp* m_midiConnection;
+	NetcastManager* m_netcastManager;
 
 	// Scheme objects
-	QString                 m_currentSchemeId;
-	QString                 m_currentMidiConn;
-	QHash<QString, QString> m_schemeSources;
 //	QString                 m_schemeHomeDir;
 	QList<QGraphicsItem*>   m_guiItems;
 
