@@ -97,6 +97,7 @@ void MidiObjectUdp::devOpen(QString device)
 	m_deviceName = device;
 	UdpPorts udpPorts = m_deviceUdpPortsMap.value(device);
 	m_targetPort = udpPorts.targetPort;
+	m_targetAddress = QHostAddress::Broadcast;
 
 	qDebug() << "MidiObjectUdp: bind port" << udpPorts.bindPort << "; target port" << m_targetPort;
 	if ((m_restrictionFlags & MIDI_OBJECT_ONLY_OUTPUT) == 0) // only input or bidirectional
@@ -169,7 +170,6 @@ void MidiObjectUdp::updateDeviceList()
 	}
 }
 
-
 void MidiObjectUdp::sendShortMsg(uint word)
 {
 	qDebug() << "MidiObjectUdp::sendShortMsg() " << (Qt::HANDLE)word;
@@ -180,7 +180,7 @@ void MidiObjectUdp::sendShortMsg(uint word)
 	qDebug() << "MidiObjectUdp::sendShortMsg() to localhost:" << m_targetPort;
 	m_socket->writeDatagram(datagram.data(), datagram.size(), QHostAddress::LocalHost, m_targetPort);
 #else
-	m_socket->writeDatagram(datagram.data(), datagram.size(), QHostAddress::Broadcast, m_targetPort);
+	m_socket->writeDatagram(datagram.data(), datagram.size(), m_targetAddress, m_targetPort);
 #endif
 }
 
@@ -200,7 +200,7 @@ void MidiObjectUdp::sendSysexMsg(unsigned char data[], unsigned int length)
 	qDebug() << "MidiObjectUdp::sendShortMsg() to localhost:" << port;
 	m_socket->writeDatagram((const char*)data, length, QHostAddress::LocalHost, port);
 #else
-	m_socket->writeDatagram((const char*)data, length, QHostAddress::Broadcast, port);
+	m_socket->writeDatagram((const char*)data, length, m_targetAddress, port);
 #endif
 }
 
@@ -243,3 +243,23 @@ void MidiObjectUdp::processDatagram(const QByteArray& datagram)
 		}
 	}
 }
+
+
+void MidiObjectUdp::setParams(Params* pParams)
+{
+	if (pParams == NULL)
+		return;
+
+	QHostAddress testAddress;
+	if (!pParams->targetIp.isEmpty() && testAddress.setAddress(pParams->targetIp))
+	{
+		m_targetAddress = testAddress;
+	}
+	else
+	{
+		m_targetAddress = QHostAddress(QHostAddress::Broadcast);
+		// invalid IP
+		pParams->targetIp.clear();
+	}
+	qDebug(QString("MidiObjectUdp - TargetIP: %1").arg(m_targetAddress.toString()).toAscii());
+}
