@@ -32,7 +32,7 @@ public:
 
 protected:
 	QList<GraphicsMidiControlItem*> m_midiControls;
-	QHash<ushort, QHash<GraphicsMidiControlItem*, ushort> > m_states;
+	QHash<ushort, QHash<GraphicsMidiControlItem*, ulong> > m_states;
 };
 
 #endif /* GRAPHICSMIDIMULTIITEM_H_ */
