@@ -25,7 +25,7 @@
 #include "GuiUtils.h"
 #include "ACMidiDefines.h"
 #include "MidiSysexAction.h"
-#include <MidiJ.h>
+//XXX #include <MidiJ.h>
 
 QByteArray& operator<<(QByteArray& ba, int n)
 {
