@@ -33,7 +33,6 @@ int main(int argc, char *argv[])
 #ifdef Q_WS_WIN
     w.setWindowTitle(QString::fromUtf8("MidiJ"));
     w.resize(480, 800);
-    QString home = "data/";
     QString schemeDir = "data/schemes/";
     QString altSchemeDir = "data/userSchemes/MidiJ_SSL_V1.0/midij_schemes";
     w.setWindowIcon(QIcon("icon/64x64/midij.png"));
@@ -43,16 +42,14 @@ int main(int argc, char *argv[])
     QApplication::setOverrideCursor(QCursor(Qt::BlankCursor));
     w.setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
     w.setWindowState(Qt::WindowFullScreen);
-    QString home = "/opt/midij/";
     QString schemeDir = "/opt/midij/schemes/";
     QString altSchemeDir = "/home/user/MyDocs/.midij_schemes/";
 #endif // Q_WS_MAEMO_5
 
-
     w.showLoadingScreen(true);
 	w.show();
 	a.processEvents(QEventLoop::ExcludeUserInputEvents);
-	if (!w.init(home, schemeDir, altSchemeDir))
+	if (!w.init(schemeDir, altSchemeDir))
 		return 0;
 
 	QTimer::singleShot(250, &w, SLOT(loadCurrentScheme()));
